@@ -11,8 +11,8 @@
 //
 // You should have received a copy of the GNU Lesser General Public License
 // along with this library; see the file COPYING.LIB.  If not, write to
-// the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-// Boston, MA 02111-1307, USA.
+// the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+// Boston, MA 02110-1301, USA.
 
 #ifndef LIBATLANTIC_CORE_H
 #define LIBATLANTIC_CORE_H
@@ -20,29 +20,43 @@
 #include <qobject.h>
 #include <qptrlist.h>
 
+#include "libatlantic_export.h"
+
 class Player;
+class ConfigOption;
 class Estate;
 class EstateGroup;
+class Game;
 class Trade;
 class Auction;
 
-class AtlanticCore : public QObject
+class LIBATLANTIC_EXPORT AtlanticCore : public QObject
 {
 Q_OBJECT
 
 public:
 	AtlanticCore(QObject *parent, const char *name);
 
-	void reset(bool deletePlayers = false);
+	void reset(bool deletePermanents = false);
+
+	bool selfIsMaster() const;
 
 	void setPlayerSelf(Player *player);
 	Player *playerSelf();
 
 	QPtrList<Player> players();
-	Player *newPlayer(int playerId);
+	Player *newPlayer(int playerId, const bool &playerSelf = false);
 	Player *findPlayer(int playerId);
 	void removePlayer(Player *player);
 
+	QPtrList<Game> games();
+	Game *newGame(int gameId, const QString &type = QString::null);
+	Game *findGame(const QString &type); // finds game types
+	Game *findGame(int gameId); // finds actual games
+	Game *gameSelf();
+	void removeGame(Game *game);
+	void emitGames();
+
 	QPtrList<Estate> estates();
 	Estate *newEstate(int estateId);
 	Estate *findEstate(int estateId);
@@ -61,19 +75,31 @@ public:
 	Auction *newAuction(int auctionId, Estate *estate);
 	void delAuction(Auction *auction);
 
+	ConfigOption *newConfigOption(int configId);
+	void removeConfigOption(ConfigOption *configOption);
+	ConfigOption *findConfigOption(int configId);
+
+	void printDebug();
+
 signals:
+	void createGUI(Player *player);
 	void removeGUI(Player *player);
-	void deletePlayer(Player *player);
+	void createGUI(Game *game);
+	void removeGUI(Game *game);
+	void createGUI(Trade *trade);
 	void removeGUI(Trade *trade);
-	void deleteTrade(Trade *trade);
+	void createGUI(ConfigOption *configOption);
+	void removeGUI(ConfigOption *configOption);
 
 private:
 	Player *m_playerSelf;
 	QPtrList<Player> m_players;
+	QPtrList<Game> m_games;
 	QPtrList<Estate> m_estates;
 	QPtrList<EstateGroup> m_estateGroups;
 	QPtrList<Trade> m_trades;
 	QPtrList<Auction> m_auctions;
+	QPtrList<ConfigOption> m_configOptions;
 };
 
 #endif
