@@ -15,7 +15,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 */
 
@@ -74,7 +74,7 @@ void KBgBoardSetup::setupDefault()
 	pbc_3->setPalette(QPalette(baseColors[1]));
 
 	// default font
-	setFont(QFont("times", 18, QFont::Normal));
+	setFont(QFont("Serif", 18, QFont::Normal));
 	kf->setFont(getFont());
 
 	// short moves
@@ -324,7 +324,7 @@ void KBgBoard::saveConfig()
 void KBgBoard::readConfig()
 {
 	QColor col(200, 200, 166);
-	QFont fon("times", 18, QFont::Normal);
+	QFont fon("Serif", 18, QFont::Normal);
 
 	KConfig* config = kapp->config();
 	config->setGroup(name());
