@@ -22,9 +22,13 @@
 #include <qpushbutton.h>
 #include <qlineedit.h>
 #include <qspinbox.h>
+
+#include <kdialogbase.h>
+
 #include "dialogs/serverDlg.h"
 
-class KServerDialog : public serverStartDlg
+
+class KServerDialog : public KDialogBase
 {
 	Q_OBJECT
 public:
@@ -32,14 +36,14 @@ public:
 
 	QString port() const;
 	QString nickname() const;
+	QString gamename() const;
 
 public slots:
-	void slotStartClicked();
-	void slotCancelClicked();
+	virtual void slotOk();
+	virtual void slotCancel();
 
-signals:
-	void sigStartServer();
-	void sigCancelServer();
+private:
+	serverStartDlg *m_mainWidget;
 };
 
 #endif
