@@ -14,6 +14,7 @@ class QLabel;
 class QListBox;
 class QPushButton;
 class QLineEdit;
+class QTextEdit;
 
 enum GameState { NONE, SOURCE_PLANET, DEST_PLANET, SHIP_COUNT, RULER_SOURCE, RULER_DEST, AI_PLAYER };
 
@@ -30,7 +31,7 @@ public:
 
     bool isGameInProgress(void) const { return gameInProgress; };
 
-    virtual QSize sizeHint() const;
+//    virtual QSize sizeHint() const;
 
 protected slots:
     void startNewGame();
@@ -56,17 +57,23 @@ protected:
     virtual void keyPressEvent( QKeyEvent * );
 
 private:
-    void turn( void );
-    void nextTurn( void );
+    void turn();
+    void nextTurn();
+    void gameOver();
 
-    void resolveShipsInFlight( void );
+    void resolveShipsInFlight();
     void sendAttackFleet( Planet *source, Planet *dest, int ships );
     void doFleetArrival( AttackFleet *arrivingFleet );
-    void scanForSurvivors( void );
+    void scanForSurvivors();
+
+    void gameMsg(const QString &msg, Player *player = 0, Planet *planet = 0, Player *planetPlayer = 0);
 
     void changeGameBoard( bool inPlay );
-    void cleanupGame( void );
+    void cleanupGame();
+    Player *findWinner();
 
+    QString playerString(Player *player = 0);
+    
     //***************************************************************
     // Game State information
     //***************************************************************
@@ -84,6 +91,7 @@ private:
     QPushButton *endTurn;
     QLineEdit *shipCountEdit;
     QLabel *splashScreen;
+    QTextEdit *msgWidget;
 
 
     //***************************************************************
