@@ -12,7 +12,7 @@ class KSField : public Field
     KSField(QWidget *parent);
 
  private slots:
-    void removedLinesUpdated(uint i, uint removed);
+    virtual void removedUpdated();
     virtual void settingsChanged();
 };
 
