@@ -37,37 +37,27 @@ Field::Field(QWidget *parent)
     lcds->addWidget(removedList, 3, 0);
     lcds->setRowStretch(4, 1);
 
-	// level LCD + progress
-    showLevel = new KGameLCDList(this);
-    showLevel->append(new KGameLCD(2, showLevel));
-    showLevel->lcd(0)->display(1);
-    lcds->addWidget(showLevel, 5, 0);
+    // level progress
+    levelLabel = new QLabel(this);
+    levelLabel->setAlignment(AlignCenter);
+    lcds->addWidget(levelLabel, 5, 0);
     toLevel = new KProgress(this);
     toLevel->setTextEnabled(true);
-    toLevel->setFormat("%v/%m");
+    toLevel->setFormat("1");
     QWhatsThis::add(toLevel, i18n("Display the progress to complete the current level or stage."));
-    toLevel->setPercentageVisible(false);
     lcds->addWidget(toLevel, 6, 0);
     lcds->setRowStretch(7, 1);
 
 // column 2
-    // gift received shower
-    giftReceived = new GiftShower(this);
-    QWhatsThis::add(giftReceived, i18n("Light when a \"gift\" is received from previous player."));
-    top->addWidget(giftReceived, 0, 1, AlignCenter);
-
     // previous player height
-    prevHeight = new KGameProgress(0, ((const Board *)board)->matrix().height(), 0, KGameProgress::Vertical, this);
-    prevHeight->setFixedWidth(10);
-    prevHeight->setBackgroundColor(lightGray);
-    prevHeight->setTextEnabled(FALSE);
-    prevHeight->setBarColor(blue);
+    prevHeight = new PlayerProgress(board, this, "prev_progress");
     QWhatsThis::add(prevHeight, i18n("Previous player's height"));
     top->addWidget(prevHeight, 1, 1, AlignHCenter);
 
 // column 3
     // pending gift shower
-    top->addWidget(((Board *)board)->giftPool(), 0, 2, AlignCenter);
+    Board *b = static_cast<Board *>(board);
+    top->addWidget(b->giftPool(), 0, 2, AlignCenter);
 
     // shadow piece
     shadow = new Shadow(board, this);
@@ -75,17 +65,8 @@ Field::Field(QWidget *parent)
     top->addWidget(shadow, 2, 2);
 
 // column 4
-    // gift sent shower
-    giftSent = new GiftShower(this);
-    QWhatsThis::add(giftSent, i18n("Light when you send a \"gift\" to the next player."));
-    top->addWidget(giftSent, 0, 3, AlignCenter);
-
     // next player height
-    nextHeight = new KGameProgress(0,((const Board *)board)->matrix().height(), 0, KGameProgress::Vertical, this);
-    nextHeight->setFixedWidth(10);
-    nextHeight->setBackgroundColor(lightGray);
-    nextHeight->setTextEnabled(FALSE);
-    nextHeight->setBarColor(blue);
+    nextHeight = new PlayerProgress(board, this, "next_progress");
     QWhatsThis::add(nextHeight, i18n("Next player's height"));
     top->addWidget(nextHeight, 1, 3, AlignHCenter);
 
@@ -95,7 +76,7 @@ Field::Field(QWidget *parent)
     top->addLayout(vbl, 1, 4);
     vbl->addStretch(1);
 
-    labShowNext = new QLabel(i18n("Next tile"), this);
+    labShowNext = new QLabel(i18n("Next Tile"), this);
     labShowNext->setAlignment(AlignCenter);
     vbl->addWidget(labShowNext, 0);
     showNext = new ShowNextPiece(board, this);
@@ -111,16 +92,13 @@ Field::Field(QWidget *parent)
     initVariableGUI();
 }
 
-QSizePolicy Field::sizePolicy() const
-{
-    return QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
-}
-
 void Field::levelUpdated()
 {
-    showLevel->lcd(0)->display( (int)board->level() );
-    if ( board->level()>1 )
-        static_cast<KGameLCD *>(showLevel->lcd(0))->highlight();
+    toLevel->setFormat(QString::number(board->level()));
+    // necessary to update string ...
+    int p = toLevel->progress();
+    toLevel->setProgress(p+1);
+    toLevel->setProgress(p);
 }
 
 void Field::removedUpdated()
@@ -136,14 +114,10 @@ void Field::showOpponents(bool show)
     if (show) {
         prevHeight->show();
         nextHeight->show();
-        giftReceived->show();
-        giftSent->show();
         b->giftPool()->show();
     } else {
         prevHeight->hide();
         nextHeight->hide();
-        giftReceived->hide();
-        giftSent->hide();
         b->giftPool()->hide();
     }
 }
@@ -200,16 +174,15 @@ void Field::initVariableGUI()
         showScore->hide();
         showTime->show();
         QWhatsThis::add(scoreList, i18n("Display the elapsed time."));
-        showLevel->title()->setText(i18n("Stage"));
-        showLevel->lcd(0)->display((int)board->arcadeStage()+1);
-        toLevel->setRange(0, board->arcadeTodo());
+        levelLabel->setText(i18n("Stage"));
+        toLevel->setTotalSteps( board->arcadeTodo() );
     } else {
         scoreList->title()->setText(i18n("Score"));
         showScore->show();
         showTime->hide();
         QWhatsThis::add(scoreList, i18n("<qt>Display the current score.<br/>It turns <font color=\"blue\">blue</font> if it is a highscore and <font color=\"red\">red</font> if it is the best local score.</qt>"));
-        showLevel->title()->setText(i18n("Level"));
-        toLevel->setRange(0, cfactory->cbi.nbRemovedToLevel);
+        levelLabel->setText(i18n("Level"));
+        toLevel->setTotalSteps(cfactory->cbi.nbRemovedToLevel);
     }
 }
 
@@ -219,10 +192,8 @@ void Field::_playFlag(QDataStream &s)
     s >> spd;
     prevHeight->setValue(spd.prevHeight);
     nextHeight->setValue(spd.nextHeight);
-    if (spd.gift) {
-        giftReceived->set();
+    if (spd.gift)
         static_cast<Board *>(board)->giftPool()->put(spd.gift);
-    }
 }
 
 void Field::_pauseFlag(bool p)
@@ -245,7 +216,6 @@ void Field::_dataOut(QDataStream &s)
     _cpd.end    = static_cast<Board *>(board)->isGameOver();
     _cpd.gift   = static_cast<Board *>(board)->gift();
     s << _cpd;
-    if (_cpd.gift) giftSent->set();
 }
 
 KExtHighscore::Score Field::currentScore() const
